"""Has a single class: Game"""

# standard library imports
from abc import ABC
import asyncio

# discord imports
import discord

# local imports
from .players import Player


class Game(ABC):
	"""This (abstract) class is a template for main-game-loop objects for games"""

	@classmethod
	def name(cls):
		return "Game"

	player_cls = Player

	def __init__(self, bot, channel):
		self.bot = bot
		self.channel = channel
		self.running = False
		self.player_list = []

	async def send(self, message):
		await self.channel.send(embed=discord.Embed(description=message, color=0x00ffff))

	async def for_all_player(self, call):
		await asyncio.gather(*[call(p) for p in self.player_list])

	async def set_players(self, msg):
		self.player_list = [await self.player_cls.make(mem, self) for mem in msg.mentions]
		await self.send(f"Players: {', '.join(p.name() for p in self.player_list)}")  # send confirmation

	def check(self):
		pass

	def setup(self):
		pass

	def end(self):
		self.running = False

	async def round(self):
		pass
